RecordedInspectType

Enum RecordedInspectType 

pub enum RecordedInspectType {
Show 13 variants Node(Node), BoolProperty(BoolProperty), BytesProperty(BytesProperty), DoubleProperty(DoubleProperty), IntProperty(IntProperty), StringProperty(StringProperty), UintProperty(UintProperty), DoubleArray(DoubleArrayProperty), IntArray(IntArrayProperty), StringArray(StringArrayProperty), UintArray(UintArrayProperty), LazyNode(LazyNode), Boxed(Box<dyn InspectType>),
}
An enum representing any standard Inspect type that can be recorded in a ValueList.

Types that are 16 bytes or less are stored directly in the enum. Types that are larger than 16 bytes must be boxed in a Boxed variant.

Variants



Node(Node)



BoolProperty(BoolProperty)



BytesProperty(BytesProperty)



DoubleProperty(DoubleProperty)



IntProperty(IntProperty)



StringProperty(StringProperty)



UintProperty(UintProperty)



DoubleArray(DoubleArrayProperty)



IntArray(IntArrayProperty)



StringArray(StringArrayProperty)



UintArray(UintArrayProperty)



LazyNode(LazyNode)



Boxed(Box<dyn InspectType>)