pub struct Heap<T> { /* private fields */ }Expand description
The inspect heap.
Implementations
Sourceimpl<T: ReadBytes + WriteBytes> Heap<T>
impl<T: ReadBytes + WriteBytes> Heap<T>
Sourcepub fn new(container: T) -> Result<Self, Error>
pub fn new(container: T) -> Result<Self, Error>
Creates a new heap on the underlying mapped VMO and initializes the header block in it.
Sourcepub fn empty(container: T) -> Result<Self, Error>
pub fn empty(container: T) -> Result<Self, Error>
Creates a new heap on the underlying mapped VMO without initializing the header block.
Sourcepub fn current_size(&self) -> usize
pub fn current_size(&self) -> usize
Returns the current size of this heap in bytes.
Sourcepub fn maximum_size(&self) -> usize
pub fn maximum_size(&self) -> usize
Returns the maximum size of this heap in bytes.
Sourcepub fn total_allocated_blocks(&self) -> usize
pub fn total_allocated_blocks(&self) -> usize
Returns the number of blocks allocated since the creation of this heap.
Sourcepub fn total_deallocated_blocks(&self) -> usize
pub fn total_deallocated_blocks(&self) -> usize
Returns the number blocks deallocated since the creation of this heap.
Sourcepub fn failed_allocations(&self) -> usize
pub fn failed_allocations(&self) -> usize
Returns the number of failed allocations since the creation of this heap.
Sourcepub fn allocate_block(&mut self, min_size: usize) -> Result<BlockIndex, Error>
pub fn allocate_block(&mut self, min_size: usize) -> Result<BlockIndex, Error>
Allocates a new block of the given min_size.
Sourcepub fn free_block(&mut self, block_index: BlockIndex) -> Result<(), Error>
pub fn free_block(&mut self, block_index: BlockIndex) -> Result<(), Error>
Marks the memory region pointed by the given block as free.