Property

Trait Property 

pub trait Property<'t>: InspectTypeInternal {
    type Type;

    // Required method
    fn set(&self, value: Self::Type);

    // Provided method
    fn atomic_update<R, F: FnOnce(&Self) -> R>(&self, update_fn: F) -> R { ... }
}
Trait implemented by properties.

Required Associated Types

type Type

The type of the property.

Required Methods

fn set(&self, value: Self::Type)

Set the property value to |value|.

Provided Methods

fn atomic_update<R, F: FnOnce(&Self) -> R>(&self, update_fn: F) -> R

Takes a function to execute as under a single lock of the Inspect VMO. This function receives a reference to the Property on which it is called.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors